@@ -87,9 +87,9 @@ class MongoScheduler(Scheduler):
         else:
             db = "celery"
         if hasattr(current_app.conf, "CELERY_MONGODB_SCHEDULER_URL"):
-            self._mongo = mongoengine.connect(db, current_app.conf.CELERY_MONGODB_SCHEDULER_URL)
+            self._mongo = mongoengine.connect(db, host=current_app.conf.CELERY_MONGODB_SCHEDULER_URL)
             get_logger(__name__).info("backend scheduler using %s/%s:%s",
-                    current_app.conf.CELERY_MONGODB_SCHEDULER_DB,
+                    current_app.conf.CELERY_MONGODB_SCHEDULER_URL,
                     db, get_periodic_task_collection())
         else:
             self._mongo = mongoengine.connect(db)
